module WorkTimer

class CsvExportWriter

public

   def export(filename, theTimeClock, startTime, endTime)
      retString = ""
            
      eventHash = theTimeClock.createEventHash(startTime, endTime)
      
      #Divide the time interval into days
      numDays = (endTime - startTime) / (3600 * 24)
            
      if (endTime - startTime) % (3600 * 24) > 0
         numDays += 1
      end
      
      #create an array to hold the totals
      dailyTotals = Array.new(numDays,0)

      #create a hash to hold the totals for each
      #activity type
      activityTotals = Hash.new

      startTimeString = Time.at(startTime).strftime("%m/%d/%Y")
      
      # note: we're actually producing a report for the interval
      # [startTime, endTime) so we should subtract a second from
      # the end time string so that we don't lead the user to
      # think that the report includes the next day
      endTimeString = Time.at(endTime-1).strftime("%m/%d/%Y")
      
      retString += "Activity Report (#{startTimeString} - #{endTimeString})\n\n"

      retString += "Date,"
      
      eventHash.each_key {
         |desc|
         activityTotals[desc] = 0
         
         retString += "#{desc},"
      }
      
      # add a header for the Daily Total
      retString += "Daily Total (hrs)\n"
                  
      #get a summary of activities for each day
      1.upto(numDays) {
         |dayCount|
         dayStart = startTime + (dayCount - 1) * 3600 * 24
         dayEnd = dayStart + 3600 * 24
         
         retString += Time.at(dayStart).strftime("%m/%d/%Y") + ","         
                                                     
         eventHash.each_pair {
            |description, eventContainer|
            
            #get the amount of time spent in hours
            totalEventTime = eventContainer.computeTimeSpent(dayStart, dayEnd)
            
            totalHrs      = totalEventTime / 3600.0
            
            dailyTotals[dayCount - 1] += totalHrs
            activityTotals[description] += totalHrs

            retString += sprintf("%.2f,", totalHrs)            
         }  
         
         # add the daily total
         retString += sprintf("%.2f\n", dailyTotals[dayCount - 1])    
      }
 
      # the last row is the activity total row
      retString += "\nTotal:,"
      
      grandTotalHours = 0
      
      # now, let's iterate over the activity totals
      activityTotals.each_pair {
         |desc, value|
         grandTotalHours += value
         
         retString += sprintf("%.2f,", value)
      }

      # now add a final data point for the grandTotal
      retString += sprintf("%.2f\n", grandTotalHours)
     
      theFile = File.open(filename, "w")
      
      theFile.puts(retString)   
      
      theFile.close
   end
end

end